// This file is part of the Attempto Java Packages.
// Copyright 2008-2009, Attempto Group, University of Zurich (see http://attempto.ifi.uzh.ch).
//
// The Attempto Java Packages is free software: you can redistribute it and/or modify it under the
// terms of the GNU Lesser General Public License as published by the Free Software Foundation,
// either version 3 of the License, or (at your option) any later version.
//
// The Attempto Java Packages is distributed in the hope that it will be useful, but WITHOUT ANY
// WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR
// PURPOSE. See the GNU Lesser General Public License for more details.
//
// You should have received a copy of the GNU Lesser General Public License along with the Attempto
// Java Packages. If not, see http://www.gnu.org/licenses/.

package ch.uzh.ifi.attempto.acewiki.gui.editor;

import nextapp.echo2.app.Alignment;
import nextapp.echo2.app.Column;
import nextapp.echo2.app.Extent;
import nextapp.echo2.app.Font;
import nextapp.echo2.app.Insets;
import nextapp.echo2.app.Row;
import nextapp.echo2.app.event.ActionEvent;
import nextapp.echo2.app.event.ActionListener;
import ch.uzh.ifi.attempto.acewiki.core.ontology.Comment;
import ch.uzh.ifi.attempto.acewiki.core.ontology.OntologyElement;
import ch.uzh.ifi.attempto.acewiki.core.ontology.Statement;
import ch.uzh.ifi.attempto.acewiki.gui.page.ArticlePage;
import ch.uzh.ifi.attempto.echocomp.GeneralButton;
import ch.uzh.ifi.attempto.echocomp.Style;
import ch.uzh.ifi.attempto.echocomp.TextArea;
import ch.uzh.ifi.attempto.echocomp.WindowPane;

/**
 * This class represents the editor window that is used to create and edit comments.
 * 
 * @author Tobias Kuhn
 */
public class CommentEditorWindow extends WindowPane implements ActionListener {
	
	private static final long serialVersionUID = -8313716974943714079L;
	
	private Statement statement;
	private ArticlePage page;
	private boolean edit;
	
	private TextArea textArea;
	private GeneralButton okButton;
	private GeneralButton cancelButton;
	
	/**
	 * Creates a new comment editor window that can be used to either create a new comment
	 * or to edit an existing comment.
	 * 
	 * @param statement The statement in front of which the new comment should be added (in the
	 *   case of edit=false) or the comment that should be edited (in the case of edit=true).
	 * @param page The host page of the comment.
	 * @param edit true if an existing comment should be edited, or false if a new comment should
	 *   be created.
	 */
	public CommentEditorWindow(Statement statement, ArticlePage page, boolean edit) {
		this.statement = statement;
		this.page = page;
		this.edit = edit;
		
		setModal(true);
		setTitle("Comment Editor");
		setTitleFont(new Font(Style.fontTypeface, Font.ITALIC, new Extent(13)));
		setWidth(new Extent(500));
		setHeight(new Extent(300));
		setResizable(false);
		setTitleBackground(Style.windowTitleBackground);
		setStyleName("Default");
		
		Column mainColumn = new Column();
		mainColumn.setInsets(new Insets(10, 10));
		mainColumn.setCellSpacing(new Extent(10));
		
		textArea = new TextArea(455, 195);
		textArea.setFont(new Font(Style.fontTypeface, Font.ITALIC, new Extent(13)));
		if (edit) {
			textArea.setText(statement.getText());
		}
		mainColumn.add(textArea);
		
		Row buttonBar = new Row();
		buttonBar.setAlignment(new Alignment(Alignment.RIGHT, Alignment.CENTER));
		buttonBar.setCellSpacing(new Extent(5));
		okButton = new GeneralButton("OK", 70, this);
		buttonBar.add(okButton);
		cancelButton = new GeneralButton("Cancel", 70, this);
		buttonBar.add(cancelButton);
		mainColumn.add(buttonBar);
		
		add(mainColumn);
	}
	
	public void actionPerformed(ActionEvent e) {
		if (e.getSource() == okButton) {
			if (edit) {
				OntologyElement owner = page.getOntologyElement();
				owner.edit(statement, new Comment(textArea.getText(), owner));
				page.update();
			} else {
				OntologyElement owner = page.getOntologyElement();
				owner.add(statement, new Comment(textArea.getText(), owner));
				page.update();
			}
			setVisible(false);
			dispose();
		} else if (e.getSource() == cancelButton) {
			setVisible(false);
			dispose();
		}
	}

}
